@@ -33,6 +33,8 @@
 #' The values in column 'id' should be used to download a selected dataset.
 #' @details The TOC in English by ref_area is downloaded from \url{http://www.ilo.org/ilostat-files/WEB_bulk_download/ref_area/table_of_contents_en.csv}. 
 #' The values in column 'id' should be used to download a selected dataset.
+#' @details The TOC in English by modelled_estimates is downloaded from \url{http://www.ilo.org/ilostat-files/WEB_bulk_download/modelled_estimates/table_of_contents_en.csv}. 
+#' The values in column 'id' should be used to download a selected dataset.
 #' @references
 #' See citation("Rilostat")
 #' ilostat bulk download facility user guidelines \url{http://www.ilo.org/ilostat-files/WEB_bulk_download/ILOSTAT_BulkDownload_Guidelines.pdf} 
@@ -41,29 +43,29 @@
 #' @examples
 #' \dontrun{
 #' ## default segment by indicator, default lang English
-#' 		toc <- get_ilostat_toc()
-#' 		head(toc)
-#' 		toc <- get_ilostat_toc(segment = 'ref_area', lang = 'fr')
-#' 		head(toc)
+#'  toc <- get_ilostat_toc()
+#'  head(toc)
+#'  toc <- get_ilostat_toc(segment = 'ref_area', lang = 'fr')
+#'  head(toc)
 #' ##
 #' ## search on toc
-#'   	toc <- get_ilostat_toc(search = 'education')
-#'   	head(toc)
-#'   	toc <- get_ilostat_toc(lang = 'fr', search = 'éducation')
-#'   	head(toc)
-#'   	toc <- get_ilostat_toc(segment = 'ref_area', lang = 'fr', search = 'Albanie')
-#'   	toc
-#'   	toc <- get_ilostat_toc(segment = 'ref_area', lang = 'es', search = 'Trimestral')
-#'   	head(toc)
+#'  toc <- get_ilostat_toc(search = 'education')
+#'  head(toc)
+#'  toc <- get_ilostat_toc(lang = 'fr', search = 'éducation')
+#'  head(toc)
+#'  toc <- get_ilostat_toc(segment = 'ref_area', lang = 'fr', search = 'Albanie')
+#'  toc
+#'  toc <- get_ilostat_toc(segment = 'ref_area', lang = 'es', search = 'Trimestral')
+#'  head(toc)
 #' ##
 #' ## search multi on toc
-#'      toc <- get_ilostat_toc(segment = 'ref_area', lang = 'fr', 
+#'  toc <- get_ilostat_toc(segment = 'ref_area', lang = 'fr', 
 #'              search = 'Albanie|France', fixed = FALSE)
-#'		head(toc)
-#' 		toc <- get_ilostat_toc(search = 'youth|adult', fixed = FALSE)
-#'		head(toc)
-#' 		toc <- get_ilostat_toc(search = c('youth','adult'), fixed = FALSE)
-#'		head(toc)
+#'  head(toc)
+#'  toc <- get_ilostat_toc(search = 'youth|adult', fixed = FALSE)
+#'  head(toc)
+#'  toc <- get_ilostat_toc(search = c('youth','adult'), fixed = FALSE)
+#'  head(toc)
 #' ##
 #' }
 #' @export
@@ -87,13 +89,13 @@ get_ilostat_toc <- function(segment = getOption('ilostat_segment', 'indicator'),
   
   if(segment == 'modelled_estimates'){
   
-    y <- filter_(y, "file_type %in% 'dta'")
+    y <- filter(y, eval(parse(text = "stringr:::str_detect(file_type,'dta')")))
   
   }
   
   if(!is_tibble(y)){
   
-  	  stop("the toc file : ", ilostat_url(),segment, "/", "table_of_contents_",lang,".csv does not exist")
+      stop("the toc file : ", ilostat_url(),segment, "/", "table_of_contents_",lang,".csv does not exist")
   
   }
   
@@ -111,7 +113,7 @@ get_ilostat_toc <- function(segment = getOption('ilostat_segment', 'indicator'),
 	
 	y$titles <- paste0(y[[2]], y[[3]], y[[4]], y[[5]], y[[11]], y[[12]], y[[13]], y[[14]])
 	
-	y <- filter_(y, newsearch)[names(y) != 'titles'] 
+	y <- filter(y, eval(parse(text = newsearch)))[names(y) != 'titles'] 
    
   }
    
@@ -123,7 +125,7 @@ get_ilostat_toc <- function(segment = getOption('ilostat_segment', 'indicator'),
 	  
     if(!is.null(filters)){
         
-	  y <- filter_(y, filters)
+	  y <- filter(y, eval(parse(text = filters)))
 	  
     }
   }	
